Code style: Rename BinaryXML to BinaryXml
diff --git a/ndn-cpp/c/encoding/BinaryXMLStructureDecoder.h b/ndn-cpp/c/encoding/BinaryXMLStructureDecoder.h
index 603ee43..8c561a1 100644
--- a/ndn-cpp/c/encoding/BinaryXMLStructureDecoder.h
+++ b/ndn-cpp/c/encoding/BinaryXMLStructureDecoder.h
@@ -12,7 +12,7 @@
 extern "C" {
 #endif
 
-struct ndn_BinaryXMLStructureDecoder {
+struct ndn_BinaryXmlStructureDecoder {
   int gotElementEnd; /**< boolean */
   unsigned int offset;
   int level;
@@ -25,31 +25,31 @@
 };
 
 enum {
-  ndn_BinaryXMLStructureDecoder_READ_HEADER_OR_CLOSE,
-  ndn_BinaryXMLStructureDecoder_READ_BYTES
+  ndn_BinaryXmlStructureDecoder_READ_HEADER_OR_CLOSE,
+  ndn_BinaryXmlStructureDecoder_READ_BYTES
 };
 
-void ndn_BinaryXMLStructureDecoder_init(struct ndn_BinaryXMLStructureDecoder *self);
+void ndn_BinaryXmlStructureDecoder_init(struct ndn_BinaryXmlStructureDecoder *self);
         
 /**
  * Continue scanning input starting from self->offset to find the element end.  On return, you must check
  *   self->gotElementEnd: If the end of the element which started at offset 0 is found, 
  *   then self->gotElementEnd is 1 and self->offset is the length of the element.  Otherwise, self-forElementEnd is 0 
  *   which means you should read more into input and call again.
  * @param self pointer to the ndn_BinaryXMLStructureDecoder struct
  * @param input the input buffer. You have to pass in input each time because the buffer could be reallocated.
  * @param inputLength the number of bytes in input.
  * @return 0 for success, else an error code
  */
-ndn_Error ndn_BinaryXMLStructureDecoder_findElementEnd
-  (struct ndn_BinaryXMLStructureDecoder *self, unsigned char *input, unsigned int inputLength);
+ndn_Error ndn_BinaryXmlStructureDecoder_findElementEnd
+  (struct ndn_BinaryXmlStructureDecoder *self, unsigned char *input, unsigned int inputLength);
 
 /**
  * Set the offset into the input, used for the next read.
  * @param self pointer to the ndn_BinaryXMLStructureDecoder struct
  * @param offset the new offset
  */
-static inline void ndn_BinaryXMLStructureDecoder_seek(struct ndn_BinaryXMLStructureDecoder *self, unsigned int offset) 
+static inline void ndn_BinaryXmlStructureDecoder_seek(struct ndn_BinaryXmlStructureDecoder *self, unsigned int offset) 
 {
   self->offset = offset;
 }
@@ -25,31 +25,31 @@
  *   then self->gotElementEnd is 1 and self->offset is the length of the element.  Otherwise, self-forElementEnd is 0 
  *   which means you should read more into input and call again.
- * @param self pointer to the ndn_BinaryXMLStructureDecoder struct
+ * @param self pointer to the ndn_BinaryXmlStructureDecoder struct
  * @param input the input buffer. You have to pass in input each time because the buffer could be reallocated.
  * @param inputLength the number of bytes in input.
@@ -25,31 +25,31 @@
 /**
  * Set the offset into the input, used for the next read.
- * @param self pointer to the ndn_BinaryXMLStructureDecoder struct
+ * @param self pointer to the ndn_BinaryXmlStructureDecoder struct
  * @param offset the new offset
  */